summaryrefslogtreecommitdiffstats
path: root/docker-api
diff options
context:
space:
mode:
authorArne H Juul <arnej@yahoo-inc.com>2017-06-28 12:58:27 +0200
committerArne H Juul <arnej@yahoo-inc.com>2017-06-28 12:58:27 +0200
commit5be8b1deb34b621feb04c9625485da67a5630019 (patch)
treeca16d086ce255def4da56ecd8518f945e8633a0f /docker-api
parentf52a4c5038a0586763d130cde5beab377d4ecf5f (diff)
use underVespaHome
Diffstat (limited to 'docker-api')
-rw-r--r--docker-api/src/test/java/com/yahoo/vespa/hosted/dockerapi/RunSystemTests.java7
1 files changed, 4 insertions, 3 deletions
diff --git a/docker-api/src/test/java/com/yahoo/vespa/hosted/dockerapi/RunSystemTests.java b/docker-api/src/test/java/com/yahoo/vespa/hosted/dockerapi/RunSystemTests.java
index 9fbe103360b..5f090abec71 100644
--- a/docker-api/src/test/java/com/yahoo/vespa/hosted/dockerapi/RunSystemTests.java
+++ b/docker-api/src/test/java/com/yahoo/vespa/hosted/dockerapi/RunSystemTests.java
@@ -5,6 +5,7 @@ import com.github.dockerjava.api.command.ExecCreateCmdResponse;
import com.github.dockerjava.api.command.ExecStartCmd;
import com.github.dockerjava.api.command.InspectExecResponse;
import com.github.dockerjava.core.command.ExecStartResultCallback;
+import static com.yahoo.vespa.defaults.Defaults.getDefaults;
import com.yahoo.system.ProcessExecuter;
import java.io.IOException;
@@ -35,7 +36,7 @@ import static org.junit.Assert.assertEquals;
RunSystemTests runSystemTests = new RunSystemTests(vespaDockerBase, pathToSystemtestsInHost);
ContainerName systemtestsHost = new ContainerName("stest-1");
// Update maven local repository and /home/y/lib/jars with the current version of these modules inside container
runSystemTests.updateContainerMavenLocalRepository(systemtestsHost);
Path systemTestToRun = Paths.get("tests/search/basicsearch/basic_search.rb");
@@ -54,7 +55,7 @@ public class RunSystemTests {
private final Path pathToVespaRepoInHost = Paths.get("").toAbsolutePath();
private final Path pathToVespaRepoInContainer = Paths.get("/vespa");
private final Path pathToTestRunner = pathToSystemtestsInContainer.resolve("bin/run_test.rb");
- private final Path pathToLibJars = Paths.get("/home/y/lib/jars");
+ private final Path pathToLibJars = Paths.get(getDefaults().underVespaHome("lib/jars"));
private final String username = System.getProperty("user.name");
private final Logger logger = Logger.getLogger("systemtest");
@@ -95,7 +96,7 @@ public class RunSystemTests {
/**
* This method updates container's local repository with all artifacts that are built on host machine, then
- * copies any existing and updated file from target to /home/y/lib/jars.
+ * copies any existing and updated file from target to $VESPA_HOME/lib/jars.
*
* @param containerName name of the container to install modules in, if it does not exist, a new
* one will be started.
@@ -35,7 +36,7 @@ import static org.junit.Assert.assertEquals;
RunSystemTests runSystemTests = new RunSystemTests(vespaDockerBase, pathToSystemtestsInHost);
ContainerName systemtestsHost = new ContainerName("stest-1");
- // Update maven local repository and /home/y/lib/jars with the current version of these modules inside container
+ // Update maven local repository and $VESPA_HOME/lib/jars with the current version of these modules inside container
runSystemTests.updateContainerMavenLocalRepository(systemtestsHost);
Path systemTestToRun = Paths.get("tests/search/basicsearch/basic_search.rb");